@@ -114,7 +114,7 @@ static int pix24bpp = 0;
 #define IVTVDEV_DRIVER_NAME	"ivtv"
 #define IVTVDEV_VERSION_MAJOR	1
 #define IVTVDEV_VERSION_MINOR	1
-#define IVTVDEV_VERSION_PATCH	1
+#define IVTVDEV_VERSION_PATCH	2
 #define IVTVDEV_VERSION	((IVTVDEV_VERSION_MAJOR << 16) | \
 			(IVTVDEV_VERSION_MINOR << 8) | \
 			(IVTVDEV_VERSION_PATCH))
@@ -293,7 +293,7 @@ IVTVDevFreeRec(ScrnInfoPtr pScrn)
 {
     if (pScrn->driverPrivate == NULL)
 	return;
-    xfree(pScrn->driverPrivate);
+    free(pScrn->driverPrivate);
     pScrn->driverPrivate = NULL;
 }
 
@@ -341,7 +341,7 @@ IVTVDevProbe(DriverPtr drv, int flags)
 	return FALSE;
 
     if (flags & PROBE_DETECT) {
-	xfree(devSections);
+	free(devSections);
 	TRACE("probe done");
 	return TRUE;
     }
@@ -378,7 +378,7 @@ IVTVDevProbe(DriverPtr drv, int flags)
 	xf86DrvMsg(pScrn->scrnIndex, X_INFO,
 		"using %s\n", dev ? dev : "default device");
     }
-    xfree(devSections);
+    free(devSections);
     TRACE("probe done");
     return foundScreen;
 }
@@ -468,7 +468,7 @@ IVTVDevPreInit(ScrnInfoPtr pScrn, int flags)
 
     /* handle options */
     xf86CollectOptions(pScrn, NULL);
-    if (!(devPtr->Options = xalloc(sizeof(IVTVDevOptions))))
+    if (!(devPtr->Options = malloc(sizeof(IVTVDevOptions))))
 	return FALSE;
     memcpy(devPtr->Options, IVTVDevOptions, sizeof(IVTVDevOptions));
     xf86ProcessOptions(pScrn->scrnIndex, devPtr->pEnt->device->options,
@@ -645,7 +645,7 @@ IVTVDevScreenInit(int scrnIndex, ScreenPtr pScreen, int argc, char **argv)
     width = pScrn->virtualX;
 
     /* shadowfb */
-    if ((devPtr->shadowmem = xcalloc(1, pScrn->virtualX * pScrn->virtualY *
+    if ((devPtr->shadowmem = calloc(1, pScrn->virtualX * pScrn->virtualY *
 		pScrn->bitsPerPixel)) == NULL) {
 	xf86DrvMsg(scrnIndex, X_ERROR,
 	    "DevScreenInit: Allocation of shadow memory failed\n");
@@ -718,7 +718,7 @@ IVTVDevScreenInit(int scrnIndex, ScreenPtr pScreen, int argc, char **argv)
     IvtvInitVideo(pScreen);
 
     /* Allocate buffer for yv12 to hm12 conversion */
-    devPtr->xv_buffer = xalloc(622080);
+    devPtr->xv_buffer = malloc(622080);
     if (!devPtr->xv_buffer) {
 	xf86DrvMsg(pScrn->scrnIndex, X_ERROR,
 	    "DevScreenInit: Failed to allocate xv conversion buffer\n");
@@ -747,11 +747,11 @@ IVTVDevCloseScreen(int scrnIndex, ScreenPtr pScreen)
     ivtvHWUnmapVidmem(pScrn);
 #endif
     ivtvHWRestore(pScrn);
-    xfree(devPtr->shadowmem);
+    free(devPtr->shadowmem);
     pScrn->vtSema = FALSE;
 
     if (devPtr->xv_buffer) {
-	xfree(devPtr->xv_buffer);
+	free(devPtr->xv_buffer);
 	devPtr->xv_buffer = 0;
     }
 
