@@ -55,8 +55,12 @@ in this Software without prior written authorization from the XFree86 Project.
 #include "xf86cmap.h"
 
 #include "globals.h"
-#define DPMS_SERVER
-#include <X11/extensions/dpms.h>
+#ifdef HAVE_XEXTPROTO_71
+# include <X11/extensions/dpmsconst.h>
+#else
+# define DPMS_SERVER
+# include <X11/extensions/dpms.h>
+#endif
 
 #if IVTVDEBUG
 # define TRACE_ENTER(str)	ErrorF("ivtv_hw: " str " %d\n",pScrn->scrnIndex)
